#
# spec file for package python-patsy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15allpythons}
Name:           python-patsy
Version:        1.0.1
Release:        1.2
Summary:        A Python package for statistical models and design matrices
License:        BSD-2-Clause
URL:            https://github.com/pydata/patsy
Source:         https://files.pythonhosted.org/packages/source/p/patsy/patsy-%{version}.tar.gz
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Recommends:     python-scipy
BuildArch:      noarch
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
%python_subpackages

%description
A Python package for describing statistical models and for
building design matrices.
It is closely inspired by and compatible with the 'formula'
mini-language used in `R <http://www.r-project.org/>`_ and
`S <https://secure.wikimedia.org/wikipedia/en/wiki/S_programming_language>`_.

%prep
%autosetup -p1 -n patsy-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc README.md
%{python_sitelib}/patsy/
%{python_sitelib}/patsy-%{version}.dist-info

%changelog
* Tue Dec 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.1:
  * Add explicit support for Python 3.13.
  * Drop support for Python 2.7, and remove dependency on the six module.
  * Fix compatibility with numpy >= 2.
- Remove multibuild, no longer in a loop with pandas.
- Drop patch python-patsy-no-python2.patch, included upstream.
- Switch to pyproject macros.
* Wed Nov  6 2024 pgajdos@suse.com
- drop python 2 support
- added patches
  fix https://github.com/pydata/patsy/pull/209
  + python-patsy-no-python2.patch
* Tue Sep 10 2024 Markéta Machová <mmachova@suse.com>
- Skip tests failing with numpy 2
* Wed Mar 27 2024 Christian Keil <keil@dfn-cert.de>
- Add Python 3.11 build.
* Tue Jan  9 2024 Dirk Müller <dmueller@suse.com>
- update to 0.5.6:
  * Avoid using deprecated is_categorical_dtype from pandas at
    all in pandas >=0.25.
  * Avoid using deprecated numpy.row_stack in favor of
    numpy.vstack.
  * Handle deprecation of _is_categorical_dtype in pandas.
  * Replace numpy.issubsctype usage with numpy.issubdtype for
    compatibility with numpy 2.0.
  * Add support for Python 3.12, and fix broken unit tests in
    this version.
* Thu Feb  9 2023 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 0.5.3:
  * Officially add support for Python 3.10 and 3.11, and extend test
    coverage to include these releases.
  * Fix handling of future interpreter features that no longer have a
    mandatory release version, as for the `annotations` feature (See
    `#187 <https://github.com/pydata/patsy/pull/187>`__ for details.)
* Mon Nov  8 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.5.2:
  * Fix some deprecation warnings associated with importing from the
    collections module (rather than collections.abc) in Python 3.7+.
- README renamed to use Markdown.
- Drop patch python-patsy-remove-nose.patch, merged upstream.
- Remove unneeded nose BuildRequires.
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- skip python36 build
* Wed Sep  9 2020 pgajdos@suse.com
- provide pullrequest url to previous change
* Tue Sep  8 2020 pgajdos@suse.com
- run tests
- added patches
  fix https://github.com/pydata/patsy/pull/162
  + python-patsy-remove-nose.patch
- added sources
  + _multibuild
* Thu Nov  1 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * removed devel from noarch
- update to version 0.5.1:
  * The Python 3.6.7 and 3.7.1 point releases changed the standard
    tokenizer module in a way that broke patsy. Updated patsy to work
    with these point releases. (See `#131
    <https://github.com/pydata/patsy/pull/131>`__ for details.)
* Thu Jan 11 2018 arun@gmx.de
- specfile:
  * update copyirght year
- update to version 0.5.0:
  * Dropped support for Python 2.6 and 3.3.
  * Update to keep up with "pandas" API changes
  * More consistent handling of degenerate linear constraints in
  * Fix a crash in "DesignMatrix.__repr__" when "shape[0] == 0"
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Nov 14 2015 arun@gmx.de
- update to version 0.4.1:
  * On Python 2, accept "unicode" strings containing only ASCII
    characters as valid formula descriptions in the high-level formula
    API (:func:`dmatrix` and friends). This is intended as a
    convenience for people using Python 2 with "from __future__
    import unicode_literals". (See :ref:`py2-versus-py3`.)
  * Accept "long" as a valid integer type in the new
    :class:`DesignInfo` classes. In particular this fixes errors that
    arise on 64-bit Windows builds (where "ndarray.shape" contains
    "long" objects), like "ValueError: For numerical factors,
    num_columns must be an int."
  * Fix deprecation warnings encountered with numpy 1.10
* Wed Jul 22 2015 toddrme2178@gmail.com
- Update to version 0.4.0
  + Incompatible changes:
  * :class:`EvalFactor` and :meth:`ModelDesc.from_formula` no longer
    take an ``eval_env`` argument.
  * The :func:`design_matrix_builders` function and the
    :meth:`factor_protocol.memorize_passes_needed` method now require an
    ``eval_env`` as an additional argument.
  * The :class:`DesignInfo` constructor's arguments have totally
    changed. In addition to the changes needed to support the new
    features below, we no longer support "shim" DesignInfo objects that
    have non-trivial term specifications. This was only included in the
    first place to provide a compatibility hook for competing formula
    libraries; four years later, no such libraries have shown up. If one
    does, we can re-add it, but I'm not going to bother maintaining it
    in the mean time...
  * Dropped support for Python 3.2.
  + Other changes:
  * Patsy now supports Pandas's new (version 0.15 or later) categorical
    objects.
  * Formulas (or more precisely, :class:`EvalFactor` objects) now only
    keep a reference to the variables required from their environment
    instead of the whole environment where the formula was
    defined. (Thanks to Christian Hudon.)
  * :class:`DesignInfo` has new attributes
    :attr:`DesignInfo.factor_infos` and :attr:`DesignInfo.term_codings`
    which provide detailed metadata about how each factor and term is
    encoded.
  * As a result of the above changes, the split between
    :class:`DesignInfo` and :class:`DesignMatrixBuilder` is no longer
    necessary; :class:`DesignMatrixBuiler` has been eliminated. So for
    example, :func:`design_matrix_builders` now returns a list of
    :class:`DesignInfo` objects, and you can now pass
    :class:`DesignInfo` objects directly to any function for building
    design matrices. For compatibility, :class:`DesignInfo` continues to
    provide ``.builder`` and ``.design_info`` attributes, so that old
    code should continue to work; however, these attributes are
    deprecated.
  * Ensured that attempting to pickle most Patsy objects raises an
    error. This has never been supported, and the interesting cases
    failed in any case, but now we're taking a more systematic
    approach. (Soon we will add real, supported pickling support.)
  * Fixed a bug when running under ``python -OO``.
- update to version 0.3.0:
  * New stateful transforms for computing natural and cylic cubic
    splines with constraints, and tensor spline bases with
    constraints. (Thanks to @broessli and GDF Suez for contributing
    this code.)
  * Dropped support for Python 2.5 and earlier.
  * Switched to using a single source tree for both Python 2 and
    Python 3.
  * Added a fast-path to skip NA detection for inputs with boolean
    dtypes (thanks to Matt Davis for patch).
  * Incompatible change: Sometimes when building a design matrix for a
    formula that does not depend on the data in any way, like "1 ~ 1",
    we have no way to determine how many rows the resulting matrix
    should have. In previous versions of patsy, when this occurred we
    simply returned a matrix with 1 row. In 0.3.0+, we instead refuse
    to guess, and raise an error.
    Note that because of the next change listed, this situation occurs less frequently in 0.3.0 than in previous versions.
  * If the data argument to :func:`build_design_matrices` (or derived
    functions like :func:`dmatrix`, :func:`dmatrices`) is a
    :class:`pandas.DataFrame`, then we now check its number of rows
    and index, and insist that the output design matrices match. This
    also means that if data is a DataFrame, then the error described
    in the first bullet above cannot occur -- we will simply return a
    column of 1s that is the same size as the input dataframe.
  * Worked around some more limitations in py2exe/py2app and friends.
- specfile:
  * update copyright year
  * changed README to README.rst
* Tue Oct 22 2013 toddrme2178@gmail.com
- Initial version (0.2.1)
